export default {
    "message": "Shorthand property assignments are valid only in destructuring patterns",
    "column": 11,
    "index": 10,
    "lineNumber": 1
}